@@ -1,9 +1,9 @@
-import pytest
 from app.init import boot
 from argostranslate import package
 
+
 def test_boot_argos():
     """Test Argos translate models initialization"""
-    boot()
+    boot(["en", "es"])
 
-    assert len(package.get_installed_packages()) > 2
\ No newline at end of file
+    assert len(package.get_installed_packages()) >= 2
